pub enum PluginDetection {
Dependency {
package: String,
},
FileExists {
pattern: String,
},
All {
conditions: Vec<Self>,
},
Any {
conditions: Vec<Self>,
},
}Expand description
How to detect if a plugin should be activated.
When set on an ExternalPluginDef, this takes priority over enablers.
Supports dependency checks, file existence checks, and boolean combinators.
Variants
Dependency
Plugin detected if this package is in dependencies.
FileExists
Plugin detected if this file pattern matches.
All
All conditions must be true.
Any
Any condition must be true.