pub fn load_root_deno_workspace_patterns(
root: &Path,
) -> Result<Option<(PathBuf, Vec<String>)>, (PathBuf, String)>Expand description
Load root Deno workspace patterns and their declaring config path.
Errors
Returns the chosen config path and parse error when a present config is malformed.