pub struct ScopedUsedClassMemberRule {
pub extends: Option<String>,
pub implements: Option<String>,
pub members: Vec<String>,
}Expand description
A heritage-constrained usedClassMembers rule.
Fields
extends: Option<String>Only apply when the class extends this parent class name.
implements: Option<String>Only apply when the class implements this interface name.
members: Vec<String>Member names or glob patterns that should be treated as framework-used.
Implementations