FrameworkRule

Type Alias FrameworkRule 

pub type FrameworkRule = FrameworkPreset;
Resolved framework rule (after loading custom presets).

Aliased Type

pub struct FrameworkRule {
    pub name: String,
    pub detection: Option<FrameworkDetection>,
    pub entry_points: Vec<FrameworkEntryPattern>,
    pub always_used: Vec<String>,
    pub used_exports: Vec<FrameworkUsedExport>,
}

Fields

name: String

Unique name for this framework.

detection: Option<FrameworkDetection>

How to detect if this framework is in use.

entry_points: Vec<FrameworkEntryPattern>

Glob patterns for files that are entry points.

always_used: Vec<String>

Files that are always considered “used”.

used_exports: Vec<FrameworkUsedExport>

Exports that are always considered used in matching files.