pub enum CatalogPrecedingCommentPolicy {
Auto,
Always,
Never,
}Expand description
Policy for deleting comments immediately above removed catalog entries.
Variants
Auto
Delete the comment block when it is separated from previous siblings by a blank line, or when it directly follows the parent catalog header.
Always
Always delete the contiguous comment block immediately above the entry.
Never
Never delete leading comments; leave them in place as orphan comments.