pub fn parse_pnpm_catalog_data(source: &str) -> PnpmCatalogDataExpand description
Parse the catalog sections of a pnpm-workspace.yaml file.
Returns an empty PnpmCatalogData when the file has no catalog data, when
the YAML is malformed, or when the catalog sections are present but empty.
All non-catalog top-level keys (packages, catalog, catalogs, etc.)
are ignored.