pub struct BoundaryCoverageConfig {
pub require_all_files: bool,
pub allow_unmatched: Vec<String>,
}Expand description
Boundary zone coverage policy.
Fields
require_all_files: boolReport source files that do not match any boundary zone.
allow_unmatched: Vec<String>Glob patterns for files that may remain unmatched by any zone.