ResolvedConfig

Struct ResolvedConfig 

pub struct ResolvedConfig {
Show 21 fields pub root: PathBuf, pub entry_patterns: Vec<String>, pub ignore_patterns: GlobSet, pub output: OutputFormat, pub cache_dir: PathBuf, pub threads: usize, pub no_cache: bool, pub ignore_dependencies: Vec<String>, pub ignore_export_rules: Vec<IgnoreExportRule>, pub duplicates: DuplicatesConfig, pub health: HealthConfig, pub rules: RulesConfig, pub boundaries: ResolvedBoundaryConfig, pub production: bool, pub quiet: bool, pub external_plugins: Vec<ExternalPluginDef>, pub dynamically_loaded: Vec<String>, pub overrides: Vec<ResolvedOverride>, pub regression: Option<RegressionConfig>, pub codeowners: Option<String>, pub public_packages: Vec<String>,
}
Fully resolved configuration with all globs pre-compiled.

Fields

root: PathBufentry_patterns: Vec<String>ignore_patterns: GlobSetoutput: OutputFormatcache_dir: PathBufthreads: usizeno_cache: boolignore_dependencies: Vec<String>ignore_export_rules: Vec<IgnoreExportRule>duplicates: DuplicatesConfighealth: HealthConfigrules: RulesConfigboundaries: ResolvedBoundaryConfig

Resolved architecture boundary configuration with pre-compiled glob matchers.

production: bool

Whether production mode is active.

quiet: bool

Suppress progress output and non-essential stderr messages.

external_plugins: Vec<ExternalPluginDef>

External plugin definitions (from plugin files + inline framework definitions).

dynamically_loaded: Vec<String>

Glob patterns for dynamically loaded files (treated as always-used).

overrides: Vec<ResolvedOverride>

Per-file rule overrides with pre-compiled glob matchers.

regression: Option<RegressionConfig>

Regression config (passed through from user config, not resolved).

codeowners: Option<String>

Optional CODEOWNERS file path (passed through for --group-by owner).

public_packages: Vec<String>

Workspace package name patterns that are public libraries. Exports from these packages are not flagged as unused.

Implementations

Source

impl ResolvedConfig

pub fn resolve_rules_for_path(&self, path: &Path) -> RulesConfig

Resolve the effective rules for a given file path. Starts with base rules and applies matching overrides in order.